@@ -4,4 +4,4 @@ from PIL import ImageFont
 
 from .constants import *
 
-from .simpil_image import SimpilImage
+from .simpil_image import SimpilImage, BytesIO
