@@ -1,9 +1,9 @@
 
 # Variables for setup (these must be string only!)
 __module_name__ = u'simpil'
-__description__ = u'Simplifies use is Pillow for adding text to images'
+__description__ = u'Simplifies the use of Pillow for some basic tasks'
 
-__version__ = u'1.3.0'
+__version__ = u'1.5.0'
 
 __author__ = u'Hywel Thomas'
 __authorshort__ = u'HT'
